<?php 

/**
 * @return void
 * @since  0.1
 */
function add_post_types_support()
{
  add_post_type_support('post', 'kanews-article-json-ld');
}

add_action('wp_head', 'singular_post_json_ld', 25);

/**
 * @return void
 * @since  0.1
 */
function singular_post_json_ld()
{
    if (! is_singular() && kanews_get_option('article-json-ld') != false) {
      return;
    }

    echo get_post_json_ld();
}

/**
 * Get post JSON-LD script.
 *
 * @return string
 * @since  0.1
 */
function get_post_json_ld($post = null)
{
    $jsonld = '';
    $data = get_post_json_ld_data($post);

    if (empty($data)) {
        return $jsonld;
    }

    $jsonld = json_encode($data, JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES);
    $jsonld = '<script type="application/ld+json">' . "\n". $jsonld . "\n" . '</script>' . "\n";
    return $jsonld;
}

/**
 * Get post JSON-LD data.
 *
 * @return array
 * @since  0.1
 */
function get_post_json_ld_data($post = null)
{
    $data = [];
    $post = get_post($post);

    if (empty($post)) {
        return $data;
    }

    if (! post_type_supports($post->post_type, 'kanews-article-json-ld')) {
        return $data;
    }

    $data['@context'] = 'https://schema.org';
    $data['@id'] = "#post-{$post->ID}";
    $data['@type'] = kanews_get_option('article-json-ld-format') == 'NewsArticle' ? 'NewsArticle' : 'Article';

    $data['headline'] = get_the_title($post);
    $data['url'] = get_the_permalink($post);
    $data['mainEntityOfPage'] = true;


    $data['description'] = get_the_excerpt($post);
    

    $post_author = get_post_author_json_ld_data($post);
    if (! empty($post_author)) {
        $data['author'] = $post_author;
    }

    $post_publisher = get_post_publisher_json_ld_data($post);
    if (! empty($post_publisher)) {
        $data['publisher'] = $post_publisher;
    }

    $post_taxonomies = get_post_taxonomies($post);

    if (in_array('post_tag', $post_taxonomies, true)) {
        $post_tags = get_the_tags($post);
        if ($post_tags && ! is_wp_error($post_tags)) {
            $data['keywords'] = [];
            foreach ($post_tags as $post_tag) {
                $data['keywords'][] = $post_tag->name;
            }
        }
    }
    
    if (in_array('category', $post_taxonomies, true)) {
        $post_categories = get_the_terms($post, 'category');
        if ($post_categories && ! is_wp_error($post_categories)) {
          $data['articleSection'] = reset($post_categories)->name;
        }
    }

    $data['datePublished'] = get_the_date('c', $post);
    $data['dateModified'] = get_the_modified_date('c', $post);

    $post_thumbnail_id = get_post_thumbnail_id($post);
    if (! empty($post_thumbnail_id)) {
      $post_thumbnail_src = wp_get_attachment_image_src($post_thumbnail_id, 'full');
      if (! empty($post_thumbnail_src)) {
        $data['image'] = [
          '@type'   => 'ImageObject',
          'url'    => $post_thumbnail_src[0],
          'width'  => $post_thumbnail_src[1],
          'height' => $post_thumbnail_src[2],
        ];
      }
    }

    $data = apply_filters('post_json_ld_data', $data, $post);
    return $data;
}

/**
 * Get post author JSON-LD data.
 *
 * @return array
 * @since  0.2
 */
function get_post_author_json_ld_data($post = null)
{
    $data = [];
    $post = get_post($post);

    if (empty($post)) {
        return $data;
    }

    $post_author = get_userdata($post->post_author);

    if (empty($post_author)) {
        return $data;
    }

    $data['@type'] = 'Person';
    $data['name'] = $post_author->display_name;

    $data = apply_filters('post_author_json_ld_data', $data, $post);
    return $data;
}

/**
 * Get post publisher JSON-LD data.
 *
 * @return array
 * @since  0.1
 */
function get_post_publisher_json_ld_data($post = null)
{
    $data = [];
    $post = get_post($post);

    if (empty($post)) {
        return $data;
    }

    /* WordPress SEO plugin integration */
    if (defined('WPSEO_VERSION')) {
        if ('company' === \WPSEO_Options::get('company_or_person')) {
            $data['@type'] = 'Organization';
            $data['url'] = home_url('/');
            $data['name'] = \WPSEO_Options::get('company_name');
            $data['logo'] = [
                '@type' => 'ImageObject',
                'url'   => \WPSEO_Options::get('company_logo'),
            ];
        } elseif ('person' === \WPSEO_Options::get('company_or_person')) {
            $data['@type'] = 'Person';
            $data['url'] = home_url('/');
            $data['name'] = \WPSEO_Options::get('company_name');
        }
    }

    if (empty($data)) {
        $data['@type'] = 'Organization';
        $data['url'] = home_url('/');
        $data['name'] = get_bloginfo('name', 'display');
        $data['logo'] = kanews_get_option('logo');

        if ($data['logo']['type'] == 'img' && $data['logo']['logo-img']['url'] != '') {
          $data['logo'] = [
              '@type'   => 'ImageObject',
              'url'    => $data['logo']['logo-img']['url'],
              'width'  => $data['logo']['logo-img']['width'],
              'height' => $data['logo']['logo-img']['height'],
          ];        
        }
    }

    $data = apply_filters('ArticleJsonLd\post_publisher_json_ld_data', $data, $post);
    return $data;
}

add_action('wp_head', 'kanews_add_json_ld');
function kanews_add_json_ld(){
    $option = [
        'site_title' =>  get_bloginfo('name'),
        'site_desc' =>  get_bloginfo('description'),
        'site_url' =>  get_site_url(),
        'logo' => kanews_get_option('logo'),
    ];
    $json_ld = array(
        "@context" => "http://schema.org",
        "@type" => "Organization",
        "url" => $option['site_url'],
        "name" => $option['site_title'],
        "logo" => array(
            "@type" => "ImageObject",
            "url" => $option['logo']['logo-img']['url'],	
        ),
    );
    if(kanews_get_option('organization-json-ld') == true) {
    echo "<script type='application/ld+json'>
        ".json_encode( $json_ld )."
    </script>"; }?>
    <?php if(kanews_get_option('search-json-ld') == true): ?>
    <script type='application/ld+json'>{"@context":"http://schema.org","@type":"WebSite","url":"<?php echo $option['site_url']; ?>/","name":"<?php echo $option['site_url']; ?>","potentialAction":{"@type":"SearchAction","target":"<?php echo $option['site_url']; ?>?s={search_term_string}","query-input":"required name=search_term_string"}}</script>
<?php endif;
}
add_action('wp_head', 'kanews_add_open_graph_meta_meta');
function kanews_add_open_graph_meta_meta(){
    if(kanews_get_option('open-graph') == false)
    return false;

    if(is_single()) {
      $post = get_post();
      $cat_ID = KANEWS_WP_HELPER::primary_category_id($post->ID);
      $desc = get_the_excerpt();
      $option = [
        'title' =>  get_the_title(),
        'published' => get_the_time('c', $post->ID),
        'modified' => get_the_modified_date('c', $post->ID),
        'url' => get_permalink($post-> ID),
        'description' => $desc,
        'category' => get_cat_name( $cat_ID ),
        'image' => wp_get_attachment_image_src(get_post_thumbnail_id($post->ID), 'full'), 
        'author' => get_the_author_meta('display_name', $post->post_author), 
        'site_title' =>  get_bloginfo('name'),
        'site_desc' =>  get_bloginfo('description'),
        'site_url' =>  get_site_url(),
      ];
      echo '
        <meta property="og:locale" content="tr_TR" />
        <meta property="og:site_name" content="'. $option['site_title'] .'" />
        <meta property="og:type" content="article" />
        <meta property="og:url" content="'.$option['url'].'" />
        <meta property="og:title" content="'.$option['title'].'" />
        <meta property="og:description" content="'.$option['description'].'" />
        <meta property="article:published_time" content="'.$option['published'].'" />
        <meta property="article:section" content="'.$option['category'].'" />
        <meta name="twitter:card" content="summary_large_image" />
      ';
      if (has_post_thumbnail()) {
        echo '<meta property="og:image" content="'.$option['image'][0].'" />'."\n";
      }		
    }
  
}